# Audit Scorecard History

_Append-only. Newest entry at top. Persists across /plan:archive — do not delete._

---

## 2026-03-23

### Coverage & Mutation
| Branch coverage | 82% |
| Mutation score | deferred |
| Zero-coverage modules | 4 |

### Test Quality
| Total tests | 1127 |
| Total assertions | 2664 |
| Assertion ratio | 2.36 |
| Tests with 0 assertions | 1 |
| Skipped tests | 0 |
| Largest file assertion share | 7.7% |

### Debt
| DOC | 2 |
| ARCH | 4 |
| DESIGN | 2 |
| QUALITY | 2 |
| DATA | 0 |
| ACCESS | 0 |
| Total review cards | 10 |
| Auto-fix items | 18 |

### Test Cards
| SMELL | 1 |
| GAP | 3 |
| MUTANT | 0 |
| UPGRADE | 0 |
| SEAM | 1 |
| REDUNDANT | 0 |
| ORPHAN | 0 |
| BOSS | 2 |
| Total | 7 |

---
